summaryrefslogtreecommitdiffstats
path: root/keyboards/crkbd/keymaps
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/crkbd/keymaps')
-rw-r--r--keyboards/crkbd/keymaps/ardakilic/keymap.c8
-rw-r--r--keyboards/crkbd/keymaps/armand1m/config.h15
-rw-r--r--keyboards/crkbd/keymaps/benrestech/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/bermeo/config.h3
-rw-r--r--keyboards/crkbd/keymaps/bermeo/keymap.c32
-rw-r--r--keyboards/crkbd/keymaps/blipson/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/crkdves/config.h3
-rw-r--r--keyboards/crkbd/keymaps/crkqwes/config.h16
-rw-r--r--keyboards/crkbd/keymaps/curry/config.h1
-rw-r--r--keyboards/crkbd/keymaps/curry/keymap.c4
-rw-r--r--keyboards/crkbd/keymaps/davidrambo/config.h3
-rw-r--r--keyboards/crkbd/keymaps/devdev/config.h4
-rw-r--r--keyboards/crkbd/keymaps/devdev/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/dsanchezseco/config.h3
-rw-r--r--keyboards/crkbd/keymaps/dsanchezseco/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/edvorakjp/keymap.c12
-rw-r--r--keyboards/crkbd/keymaps/gotham/config.h2
-rw-r--r--keyboards/crkbd/keymaps/gotham/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/gotham/oled.c2
-rw-r--r--keyboards/crkbd/keymaps/hvp/config.h13
-rw-r--r--keyboards/crkbd/keymaps/hvp/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/jarred/config.h13
-rw-r--r--keyboards/crkbd/keymaps/joe_scotto/config.h4
-rw-r--r--keyboards/crkbd/keymaps/julian_turner/config.h2
-rw-r--r--keyboards/crkbd/keymaps/julian_turner/keymap.c6
-rw-r--r--keyboards/crkbd/keymaps/kidbrazil/config.h8
-rw-r--r--keyboards/crkbd/keymaps/kidbrazil/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/madhatter/config.h13
-rw-r--r--keyboards/crkbd/keymaps/mcrown/mcrown.h6
-rw-r--r--keyboards/crkbd/keymaps/mcrown/oled.c2
-rw-r--r--keyboards/crkbd/keymaps/nimishgautam/config.h2
-rw-r--r--keyboards/crkbd/keymaps/nimishgautam/keymap.c28
-rw-r--r--keyboards/crkbd/keymaps/ninjonas/README.md2
-rw-r--r--keyboards/crkbd/keymaps/ninjonas/config.h2
-rw-r--r--keyboards/crkbd/keymaps/oled_sample/config.h13
-rw-r--r--keyboards/crkbd/keymaps/oled_sample/keymap.c4
-rw-r--r--keyboards/crkbd/keymaps/ollyhayes/config.h5
-rw-r--r--keyboards/crkbd/keymaps/rarick/config.h11
-rw-r--r--keyboards/crkbd/keymaps/rarick/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/rjhilgefort/config.h14
-rw-r--r--keyboards/crkbd/keymaps/rmeli/config.h2
-rw-r--r--keyboards/crkbd/keymaps/rmeli/keymap.c11
-rw-r--r--keyboards/crkbd/keymaps/rpbaptist/config.h4
-rw-r--r--keyboards/crkbd/keymaps/rpbaptist/keymap.c21
-rw-r--r--keyboards/crkbd/keymaps/rs/config.h13
-rw-r--r--keyboards/crkbd/keymaps/snowe/config.h13
-rw-r--r--keyboards/crkbd/keymaps/snowe/keycode_aliases.h2
-rw-r--r--keyboards/crkbd/keymaps/snowe/keymap.c2
-rw-r--r--keyboards/crkbd/keymaps/soundmonster/config.h16
-rw-r--r--keyboards/crkbd/keymaps/soundmonster/keymap.c8
-rw-r--r--keyboards/crkbd/keymaps/sulrich/config.h11
-rw-r--r--keyboards/crkbd/keymaps/sulrich/keymap.c4
-rwxr-xr-xkeyboards/crkbd/keymaps/thumb_ctrl/config.h13
-rwxr-xr-xkeyboards/crkbd/keymaps/thumb_ctrl/keymap.c10
-rw-r--r--keyboards/crkbd/keymaps/thunderbird2086/layers_block.h4
-rw-r--r--keyboards/crkbd/keymaps/thunderbird2086/oled.c2
-rw-r--r--keyboards/crkbd/keymaps/toinux/config.h3
-rw-r--r--keyboards/crkbd/keymaps/toinux/keymap.c4
-rw-r--r--keyboards/crkbd/keymaps/toinux/rgb.c3
-rw-r--r--keyboards/crkbd/keymaps/vayashiko/config.h11
-rw-r--r--keyboards/crkbd/keymaps/vayashiko/keymap.c6
-rw-r--r--keyboards/crkbd/keymaps/vlukash_trackpad_left/config.h13
-rw-r--r--keyboards/crkbd/keymaps/vlukash_trackpad_left/keymap.c6
-rw-r--r--keyboards/crkbd/keymaps/vlukash_trackpad_right/config.h13
-rw-r--r--keyboards/crkbd/keymaps/vlukash_trackpad_right/keymap.c6
-rw-r--r--keyboards/crkbd/keymaps/vxid/config.h13
-rw-r--r--keyboards/crkbd/keymaps/xyverz/config.h17
67 files changed, 303 insertions, 200 deletions
diff --git a/keyboards/crkbd/keymaps/armand1m/config.h b/keyboards/crkbd/keymaps/armand1m/config.h
index 405d329640..095879a190 100644
--- a/keyboards/crkbd/keymaps/armand1m/config.h
+++ b/keyboards/crkbd/keymaps/armand1m/config.h
@@ -28,16 +28,23 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
// #define MASTER_RIGHT
// #define EE_HANDS
-#define USE_SERIAL_PD2
-
// #define TAPPING_FORCE_HOLD
// #define PERMISSIVE_HOLD
-#define TAPPING_TERM 300
+#define TAPPING_TERM 300
#define IGNORE_MOD_TAP_INTERRUPT
#ifdef RGBLIGHT_ENABLE
#undef RGBLED_NUM
- #define RGBLIGHT_ANIMATIONS
+# define RGBLIGHT_EFFECT_BREATHING
+# define RGBLIGHT_EFFECT_RAINBOW_MOOD
+# define RGBLIGHT_EFFECT_RAINBOW_SWIRL
+# define RGBLIGHT_EFFECT_SNAKE
+# define RGBLIGHT_EFFECT_KNIGHT
+# define RGBLIGHT_EFFECT_CHRISTMAS
+# define RGBLIGHT_EFFECT_STATIC_GRADIENT
+# define RGBLIGHT_EFFECT_RGB_TEST
+# define RGBLIGHT_EFFECT_ALTERNATING
+# define RGBLIGHT_EFFECT_TWINKLE
#define RGBLED_NUM 27
#define RGBLIGHT_LIMIT_VAL 120
#define RGBLIGHT_HUE_STEP 10
diff --git a/keyboards/crkbd/keymaps/benrestech/keymap.c b/keyboards/crkbd/keymaps/benrestech/keymap.c
index 8cea92be06..a79a3cc8c9 100644
--- a/keyboards/crkbd/keymaps/benrestech/keymap.c
+++ b/keyboards/crkbd/keymaps/benrestech/keymap.c
@@ -66,7 +66,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
),
[FUNL] = LAYOUT_split_3x6_3(
TO(NSSL), KC_F12, KC_F7, KC_F8, KC_F9, KC_PSCR, KC_NA, KC_NA, KC_NA, KC_NA, QK_BOOT, TO(MOUR),
- TO(NSL), KC_F11, KC_F4, KC_F5, KC_F6, KC_SLCK, KC_NA, KC_LSFT, KC_LCTL, KC_LALT, KC_LGUI, TO(NAVR),
+ TO(NSL), KC_F11, KC_F4, KC_F5, KC_F6, KC_SCRL, KC_NA, KC_LSFT, KC_LCTL, KC_LALT, KC_LGUI, TO(NAVR),
TO(BASE), KC_F10, KC_F1, KC_F2, KC_F3, KC_PAUS, KC_NA, KC_NA, KC_NA, KC_ALGR, KC_NA, TO(MEDR),
KC_APP, KC_SPC, KC_TAB, KC_NA, KC_NA, KC_NA
),
diff --git a/keyboards/crkbd/keymaps/bermeo/config.h b/keyboards/crkbd/keymaps/bermeo/config.h
index 567497afbe..cadb397834 100644
--- a/keyboards/crkbd/keymaps/bermeo/config.h
+++ b/keyboards/crkbd/keymaps/bermeo/config.h
@@ -74,10 +74,9 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
#ifdef RGB_MATRIX_ENABLE
# define RGB_MATRIX_KEYPRESSES // reacts to keypresses
// # define RGB_MATRIX_KEYRELEASES // reacts to keyreleases (instead of keypresses)
-// # define RGB_DISABLE_AFTER_TIMEOUT 0 // number of ticks to wait until disabling effects
# define RGB_DISABLE_WHEN_USB_SUSPENDED // turn off effects when suspended
# define RGB_MATRIX_FRAMEBUFFER_EFFECTS
-# define RGB_MATRIX_LED_PROCESS_LIMIT (DRIVER_LED_TOTAL + 4) / 5 // limits the number of LEDs to process in an animation per task run (increases keyboard responsiveness)
+# define RGB_MATRIX_LED_PROCESS_LIMIT (RGB_MATRIX_LED_COUNT + 4) / 5 // limits the number of LEDs to process in an animation per task run (increases keyboard responsiveness)
# define RGB_MATRIX_LED_FLUSH_LIMIT 16 // limits in milliseconds how frequently an animation will update the LEDs. 16 (16ms) is equivalent to limiting to 60fps (increases keyboard responsiveness)
# define RGB_MATRIX_MAXIMUM_BRIGHTNESS 150 // limits maximum brightness of LEDs to 150 out of 255. Higher may cause the controller to crash.
# define RGB_MATRIX_HUE_STEP 8
diff --git a/keyboards/crkbd/keymaps/bermeo/keymap.c b/keyboards/crkbd/keymaps/bermeo/keymap.c
index ad1dc92450..3b3e6d0abe 100644
--- a/keyboards/crkbd/keymaps/bermeo/keymap.c
+++ b/keyboards/crkbd/keymaps/bermeo/keymap.c
@@ -8,10 +8,10 @@
// The underscores don't mean anything - you can have a layer called STUFF or any other name.
// Layer names don't all need to be of the same length, obviously, and you can also skip them
// entirely and just use numbers.
-enum layers {
- _QWERTY,
- _LOWER,
- _RAISE,
+enum layers {
+ _QWERTY,
+ _LOWER,
+ _RAISE,
_NUMP,
};
@@ -81,13 +81,13 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {[_QWERTY] = LAYOUT
)};
//Per key lights
-void rgb_matrix_indicators_user(void) {
+bool rgb_matrix_indicators_user(void) {
#ifdef RGB_MATRIX_ENABLE
switch (get_highest_layer(layer_state)) {
case _QWERTY:
isSneaking = false;
mod_state = get_mods();
- for (int i = 0; i < DRIVER_LED_TOTAL; i++) {
+ for (int i = 0; i < RGB_MATRIX_LED_COUNT; i++) {
if (mod_state & MOD_MASK_SHIFT) {
isBarking = true;
rgb_matrix_set_color(52, 255, 255, 255);
@@ -135,7 +135,7 @@ void rgb_matrix_indicators_user(void) {
case _RAISE:
isSneaking = true;
- for (int i = 0; i < DRIVER_LED_TOTAL; i++) {
+ for (int i = 0; i < RGB_MATRIX_LED_COUNT; i++) {
switch (i) {
case 7: // B key off
case 8: // G key off
@@ -169,7 +169,7 @@ void rgb_matrix_indicators_user(void) {
case _LOWER:
isSneaking = true;
- for (int i = 0; i < DRIVER_LED_TOTAL; i++) {
+ for (int i = 0; i < RGB_MATRIX_LED_COUNT; i++) {
switch (i) {
case 7: // Delete key
case 51: // ESC key
@@ -179,7 +179,7 @@ void rgb_matrix_indicators_user(void) {
case 15: // C key off
case 20: // X key off
case 21: // Z key off
-
+
case 26: // shift key off
case 52 ... 53: // right column off
rgb_matrix_set_color(i, 0, 0, 0); // off
@@ -210,7 +210,7 @@ void rgb_matrix_indicators_user(void) {
case _NUMP:
isSneaking = true;
- for (int i = 0; i < DRIVER_LED_TOTAL; i++) {
+ for (int i = 0; i < RGB_MATRIX_LED_COUNT; i++) {
switch (i) {
case 12: // RGB speed-
case 15: // RGB brigthness-
@@ -256,6 +256,7 @@ void rgb_matrix_indicators_user(void) {
rgb_matrix_set_color(14, 0, 255, 0); // Green layer active
}
}
+ return false;
};
#endif
@@ -273,7 +274,6 @@ oled_rotation_t oled_init_user(oled_rotation_t rotation) {
# define ANIM_SIZE 96 // number of bytes in array. If you change sprites, minimize for adequate firmware size. max is 1024
/* timers */
uint32_t anim_timer = 0;
-uint32_t anim_sleep = 0;
/* current frame */
uint8_t current_frame = 0;
/* status variables */
@@ -351,19 +351,19 @@ static void render_luna(int LUNA_X, int LUNA_Y) {
current_frame = (current_frame + 1) % 2;
/* draw */
if (isBarking) {
- oled_write_raw_P(bark[abs(1 - current_frame)], ANIM_SIZE);
+ oled_write_raw_P(bark[current_frame], ANIM_SIZE);
} else if (isSneaking) {
- oled_write_raw_P(sneak[abs(1 - current_frame)], ANIM_SIZE);
+ oled_write_raw_P(sneak[current_frame], ANIM_SIZE);
} else if (current_wpm <= MIN_WALK_SPEED) {
- oled_write_raw_P(sit[abs(1 - current_frame)], ANIM_SIZE);
+ oled_write_raw_P(sit[current_frame], ANIM_SIZE);
} else if (current_wpm <= MIN_RUN_SPEED) {
- oled_write_raw_P(walk[abs(1 - current_frame)], ANIM_SIZE);
+ oled_write_raw_P(walk[current_frame], ANIM_SIZE);
} else {
- oled_write_raw_P(run[abs(1 - current_frame)], ANIM_SIZE);
+ oled_write_raw_P(run[current_frame], ANIM_SIZE);
}
}
/* animation timer */
diff --git a/keyboards/crkbd/keymaps/blipson/keymap.c b/keyboards/crkbd/keymaps/blipson/keymap.c
index 218933940c..53f45eaeb6 100644
--- a/keyboards/crkbd/keymaps/blipson/keymap.c
+++ b/keyboards/crkbd/keymaps/blipson/keymap.c
@@ -62,7 +62,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
//|----------+------------+--------------+---------------+-----------+------------| |------------+------------+------------+--------+--------+---------|
KC_LCTL, A(KC_F12), A(G(KC_LEFT)), A(G(KC_RIGHT)), S(KC_F6), C(S(KC_D)), C(S(KC_R)), G(KC_LBRC), G(KC_RBRC), KC_F11, KC_F12, KC_MPLY,
//|----------+------------+--------------+---------------+-----------+------------| |------------+------------+------------+--------+--------+---------|
- G(KC_F2), A(G(KC_F)), KC_MUTE, KC__VOLDOWN, KC__VOLUP, G(KC_GRV), C(G(KC_G)), KC_TAB, S(KC_TAB), KC_BRID, KC_BRIU, KC_CAPS,
+ G(KC_F2), A(G(KC_F)), KC_MUTE, KC_VOLD, KC_VOLU, G(KC_GRV), C(G(KC_G)), KC_TAB, S(KC_TAB), KC_BRID, KC_BRIU, KC_CAPS,
//|----------+------------+--------------+---------------+-----------+------------+--------| |--------+------------+------------+------------+--------+--------+---------|
_______, KC_LGUI, KC_SPC, KC_SPC, KC_RALT, _______
//`----------------------------------' `-------------------------------'
diff --git a/keyboards/crkbd/keymaps/crkdves/config.h b/keyboards/crkbd/keymaps/crkdves/config.h
index 4e5df394ac..52d4fdd93a 100644
--- a/keyboards/crkbd/keymaps/crkdves/config.h
+++ b/keyboards/crkbd/keymaps/crkdves/config.h
@@ -53,10 +53,9 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
#ifdef RGB_MATRIX_ENABLE
# define RGB_MATRIX_KEYPRESSES // reacts to keypresses
// # define RGB_MATRIX_KEYRELEASES // reacts to keyreleases (instead of keypresses)
-// # define RGB_DISABLE_AFTER_TIMEOUT 0 // number of ticks to wait until disabling effects
# define RGB_DISABLE_WHEN_USB_SUSPENDED // turn off effects when suspended
# define RGB_MATRIX_FRAMEBUFFER_EFFECTS
-# define RGB_MATRIX_LED_PROCESS_LIMIT (DRIVER_LED_TOTAL + 4) / 5 // limits the number of LEDs to process in an animation per task run (increases keyboard responsiveness)
+# define RGB_MATRIX_LED_PROCESS_LIMIT (RGB_MATRIX_LED_COUNT + 4) / 5 // limits the number of LEDs to process in an animation per task run (increases keyboard responsiveness)
# define RGB_MATRIX_LED_FLUSH_LIMIT 16 // limits in milliseconds how frequently an animation will update the LEDs. 16 (16ms) is equivalent to limiting to 60fps (increases keyboard responsiveness)
# define RGB_MATRIX_MAXIMUM_BRIGHTNESS 150 // limits maximum brightness of LEDs to 150 out of 255. Higher may cause the controller to crash.
# define RGB_MATRIX_HUE_STEP 8
diff --git a/keyboards/crkbd/keymaps/crkqwes/config.h b/keyboards/crkbd/keymaps/crkqwes/config.h
index 1ff720909c..878f9a74e1 100644
--- a/keyboards/crkbd/keymaps/crkqwes/config.h
+++ b/keyboards/crkbd/keymaps/crkqwes/config.h
@@ -32,8 +32,6 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
#undef USE_I2C
#undef SSD1306OLED
-#define USE_SERIAL_PD2
-
#define TAPPING_FORCE_HOLD
#define TAPPING_TERM 200
// #define RETRO_TAPPING
@@ -42,7 +40,16 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
#ifdef RGBLIGHT_ENABLE
#undef RGBLED_NUM
#define RGBLED_NUM 27
- #define RGBLIGHT_ANIMATIONS
+#define RGBLIGHT_EFFECT_BREATHING
+#define RGBLIGHT_EFFECT_RAINBOW_MOOD
+#define RGBLIGHT_EFFECT_RAINBOW_SWIRL
+#define RGBLIGHT_EFFECT_SNAKE
+#define RGBLIGHT_EFFECT_KNIGHT
+#define RGBLIGHT_EFFECT_CHRISTMAS
+#define RGBLIGHT_EFFECT_STATIC_GRADIENT
+#define RGBLIGHT_EFFECT_RGB_TEST
+#define RGBLIGHT_EFFECT_ALTERNATING
+#define RGBLIGHT_EFFECT_TWINKLE
#define RGBLIGHT_SLEEP
#define RGBLIGHT_SPLIT
#define RGBLIGHT_LIMIT_VAL 120
@@ -64,10 +71,9 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
#ifdef RGB_MATRIX_ENABLE
# define RGB_MATRIX_KEYPRESSES // reacts to keypresses
// # define RGB_MATRIX_KEYRELEASES // reacts to keyreleases (instead of keypresses)
-// # define RGB_DISABLE_AFTER_TIMEOUT 0 // number of ticks to wait until disabling effects
# define RGB_DISABLE_WHEN_USB_SUSPENDED // turn off effects when suspended
# define RGB_MATRIX_FRAMEBUFFER_EFFECTS
-# define RGB_MATRIX_LED_PROCESS_LIMIT (DRIVER_LED_TOTAL + 4) / 5 // limits the number of LEDs to process in an animation per task run (increases keyboard responsiveness)
+# define RGB_MATRIX_LED_PROCESS_LIMIT (RGB_MATRIX_LED_COUNT + 4) / 5 // limits the number of LEDs to process in an animation per task run (increases keyboard responsiveness)
# define RGB_MATRIX_LED_FLUSH_LIMIT 16 // limits in milliseconds how frequently an animation will update the LEDs. 16 (16ms) is equivalent to limiting to 60fps (increases keyboard responsiveness)
# define RGB_MATRIX_MAXIMUM_BRIGHTNESS 150 // limits maximum brightness of LEDs to 150 out of 255. Higher may cause the controller to crash.
# define RGB_MATRIX_HUE_STEP 8
diff --git a/keyboards/crkbd/keymaps/curry/config.h b/keyboards/crkbd/keymaps/curry/config.h
index ba9c69ed26..a82b4439cf 100644
--- a/keyboards/crkbd/keymaps/curry/config.h
+++ b/keyboards/crkbd/keymaps/curry/config.h
@@ -1,7 +1,6 @@
#pragma once
#define EE_HANDS
-#define USE_SERIAL_PD2
#define OLED_DISABLE_TIMEOUT
#define TAPPING_TERM_PER_KEY
diff --git a/keyboards/crkbd/keymaps/curry/keymap.c b/keyboards/crkbd/keymaps/curry/keymap.c
index 43a3147619..cbfc0cb537 100644
--- a/keyboards/crkbd/keymaps/curry/keymap.c
+++ b/keyboards/crkbd/keymaps/curry/keymap.c
@@ -9,7 +9,7 @@
KC_ESC, K01, K02, K03, K04, K05, K06, K07, K08, K09, K0A, KC_MINS, \
MT_TAB, K11, K12, K13, K14, K15, K16, K17, K18, K19, K1A, KC_QUOT, \
OS_LSFT, K21, K22, K23, K24, K25, K26, K27, K28, K29, K2A, OS_RSFT, \
- KC_LEAD,OS_LALT, SP_LWER, ET_RAIS, KC_BSPC, KC_RGUI \
+ QK_LEAD,OS_LALT, SP_LWER, ET_RAIS, KC_BSPC, KC_RGUI \
)
#define LAYOUT_crkbd_base_wrapper(...) LAYOUT_crkbd_base(__VA_ARGS__)
@@ -69,7 +69,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
[_ADJUST] = LAYOUT_wrapper( \
KC_MAKE, _________________ADJUST_L1_________________, _________________ADJUST_R1_________________, KC_RST,
- VRSN, _________________ADJUST_L2_________________, _________________ADJUST_R2_________________, EEP_RST,
+ VRSN, _________________ADJUST_L2_________________, _________________ADJUST_R2_________________, EE_CLR,
MG_NKRO, _________________ADJUST_L3_________________, _________________ADJUST_R3_________________, RGB_IDL,
_______, _______, _______, _______, TG_MODS, _______
)
diff --git a/keyboards/crkbd/keymaps/davidrambo/config.h b/keyboards/crkbd/keymaps/davidrambo/config.h
index df5e0611e1..9fb4348802 100644
--- a/keyboards/crkbd/keymaps/davidrambo/config.h
+++ b/
diff --git a/keyboards/crkbd/keymaps/ardakilic/keymap.c b/keyboards/crkbd/keymaps/ardakilic/keymap.c
index f5cd85eb12..6de8a5495c 100644
--- a/keyboards/crkbd/keymaps/ardakilic/keymap.c
+++ b/keyboards/crkbd/keymaps/ardakilic/keymap.c
@@ -30,7 +30,7 @@ enum {
_ADJUST
};
//KC_NONUS_BSLASH (\|) is equivalent to ["é] key in Turkish keyboards.
//KC_GRV (~ `) is equivalent to [<>|] key in Turkish keyboards.
// KC_SCLN is Turkish s [şŞ] key
// KC_QUOT is Turkish i [iİ] key
@@ -48,7 +48,7 @@ enum {
#define BACKTICK RALT(KC_BSLS)
#define TILDE RALT(KC_RBRC)
#define NUMBER_SIGN RALT(KC_3) //hashtag sign
-#define LOCKSCREEN LCTL(LSFT(KC_POWER)) // Screen Lock shortcut for OSX
+#define LOCKSCREEN LCTL(LSFT(KC_PWR)) // Screen Lock shortcut for OSX
/*
// Unicode Turkish characters, in case it's needed
@@ -106,7 +106,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_TAB, KC_Q, KC_W, KC_E, KC_R, KC_T, KC_Y, KC_U, KC_I, KC_O, KC_P, KC_BSPC,
LT(_NUMPAD, KC_ESC), KC_A, KC_S, KC_D, KC_F, KC_G, KC_H, KC_J, KC_K, KC_L, KC_SCLN, KC_QUOT,
LSFT_T(KC_CAPS), KC_Z, KC_X, KC_C, KC_V, KC_B, KC_N, KC_M, KC_COMM, KC_DOT, KC_SLSH, LCTL_T(KC_ENT), /*KC_ENT*/
- LGUI_T(KC_SLSH), LT(_LOWER, KC_BSLS),LT(_SPACE, KC_SPC), LT(_SODA, KC_ENT), LT(_RAISE, KC_NONUS_BSLASH), LALT_T(KC_SLSH)
+ LGUI_T(KC_SLSH), LT(_LOWER, KC_BSLS),LT(_SPACE, KC_SPC), LT(_SODA, KC_ENT), LT(_RAISE, KC_NUBS), LALT_T(KC_SLSH)
),
@@ -241,7 +241,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
),
*/
[_ADJUST] = LAYOUT_split_3x6_3(
- QK_BOOT, EEP_RST, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ QK_BOOT, EE_CLR, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
RGB_TOG, RGB_HUI, RGB_SAI, RGB_VAI, _______, _______, _______, _______, _______, _______, _______, _______,
RGB_MOD, RGB_HUD, RGB_SAD, RGB_VAD, _______, _______, _______, _______, _______, _______, _______, _______,
KC_LGUI, _______, KC_SPC, KC_ENT, _______, KC_RALT
@@ -30,7 +30,7 @@ enum {
_ADJUST
};
-//KC_NONUS_BSLASH (\|) is equivalent to ["é] key in Turkish keyboards.
+//KC_NUBS (\|) is equivalent to ["é] key in Turkish keyboards.
//KC_GRV (~ `) is equivalent to [<>|] key in Turkish keyboards.
// KC_SCLN is Turkish s [şŞ] key